[−][src]Struct parking_lot_core::UnparkResult
Result of an unpark operation.
Fields
unparked_threads: usizeThe number of threads that were unparked.
requeued_threads: usizeThe number of threads that were requeued.
have_more_threads: boolWhether there are any threads remaining in the queue. This only returns true if a thread was unparked.
be_fair: boolThis is set to true on average once every 0.5ms for any given key. It should be used to switch to a fair unlocking mechanism for a particular unlock.